/* JfifSupport.c generated by valac 0.40.4, the Vala compiler
 * generated from JfifSupport.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define TYPE_PHOTO_FILE_FORMAT_DRIVER (photo_file_format_driver_get_type ())
#define PHOTO_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriver))
#define PHOTO_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriverClass))
#define IS_PHOTO_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER))
#define IS_PHOTO_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_DRIVER))
#define PHOTO_FILE_FORMAT_DRIVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriverClass))

typedef struct _PhotoFileFormatDriver PhotoFileFormatDriver;
typedef struct _PhotoFileFormatDriverClass PhotoFileFormatDriverClass;
typedef struct _PhotoFileFormatDriverPrivate PhotoFileFormatDriverPrivate;

#define TYPE_PHOTO_FILE_FORMAT_PROPERTIES (photo_file_format_properties_get_type ())
#define PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties))
#define PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define PHOTO_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))

typedef struct _PhotoFileFormatProperties PhotoFileFormatProperties;
typedef struct _PhotoFileFormatPropertiesClass PhotoFileFormatPropertiesClass;

#define TYPE_PHOTO_FILE_ADAPTER (photo_file_adapter_get_type ())
#define PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter))
#define PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))
#define IS_PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_ADAPTER))
#define IS_PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_ADAPTER))
#define PHOTO_FILE_ADAPTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))

typedef struct _PhotoFileAdapter PhotoFileAdapter;
typedef struct _PhotoFileAdapterClass PhotoFileAdapterClass;

#define TYPE_PHOTO_FILE_READER (photo_file_reader_get_type ())
#define PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReader))
#define PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))
#define IS_PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_READER))
#define IS_PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_READER))
#define PHOTO_FILE_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))

typedef struct _PhotoFileReader PhotoFileReader;
typedef struct _PhotoFileReaderClass PhotoFileReaderClass;

#define TYPE_MEDIA_METADATA (media_metadata_get_type ())
#define MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_METADATA, MediaMetadata))
#define MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_METADATA, MediaMetadataClass))
#define IS_MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_METADATA))
#define IS_MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_METADATA))
#define MEDIA_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_METADATA, MediaMetadataClass))

typedef struct _MediaMetadata MediaMetadata;
typedef struct _MediaMetadataClass MediaMetadataClass;

#define TYPE_PHOTO_METADATA (photo_metadata_get_type ())
#define PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_METADATA, PhotoMetadata))
#define PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_METADATA, PhotoMetadataClass))
#define IS_PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_METADATA))
#define IS_PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_METADATA))
#define PHOTO_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_METADATA, PhotoMetadataClass))

typedef struct _PhotoMetadata PhotoMetadata;
typedef struct _PhotoMetadataClass PhotoMetadataClass;

#define TYPE_PHOTO_FILE_WRITER (photo_file_writer_get_type ())
#define PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriter))
#define PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))
#define IS_PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_WRITER))
#define IS_PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_WRITER))
#define PHOTO_FILE_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))

typedef struct _PhotoFileWriter PhotoFileWriter;
typedef struct _PhotoFileWriterClass PhotoFileWriterClass;

#define TYPE_PHOTO_FILE_METADATA_WRITER (photo_file_metadata_writer_get_type ())
#define PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriter))
#define PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))
#define IS_PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_METADATA_WRITER))
#define IS_PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_METADATA_WRITER))
#define PHOTO_FILE_METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))

typedef struct _PhotoFileMetadataWriter PhotoFileMetadataWriter;
typedef struct _PhotoFileMetadataWriterClass PhotoFileMetadataWriterClass;

#define PHOTO_FILE_SNIFFER_TYPE_OPTIONS (photo_file_sniffer_options_get_type ())

#define TYPE_PHOTO_FILE_SNIFFER (photo_file_sniffer_get_type ())
#define PHOTO_FILE_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer))
#define PHOTO_FILE_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSnifferClass))
#define IS_PHOTO_FILE_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_SNIFFER))
#define IS_PHOTO_FILE_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_SNIFFER))
#define PHOTO_FILE_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSnifferClass))

typedef struct _PhotoFileSniffer PhotoFileSniffer;
typedef struct _PhotoFileSnifferClass PhotoFileSnifferClass;

#define TYPE_JFIF_FILE_FORMAT_DRIVER (jfif_file_format_driver_get_type ())
#define JFIF_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver))
#define JFIF_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriverClass))
#define IS_JFIF_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_JFIF_FILE_FORMAT_DRIVER))
#define IS_JFIF_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_JFIF_FILE_FORMAT_DRIVER))
#define JFIF_FILE_FORMAT_DRIVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriverClass))

typedef struct _JfifFileFormatDriver JfifFileFormatDriver;
typedef struct _JfifFileFormatDriverClass JfifFileFormatDriverClass;
typedef struct _JfifFileFormatDriverPrivate JfifFileFormatDriverPrivate;
#define _photo_file_format_driver_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_driver_unref (var), NULL)))

#define TYPE_JFIF_FILE_FORMAT_PROPERTIES (jfif_file_format_properties_get_type ())
#define JFIF_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties))
#define JFIF_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatPropertiesClass))
#define IS_JFIF_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_JFIF_FILE_FORMAT_PROPERTIES))
#define IS_JFIF_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_JFIF_FILE_FORMAT_PROPERTIES))
#define JFIF_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatPropertiesClass))

typedef struct _JfifFileFormatProperties JfifFileFormatProperties;
typedef struct _JfifFileFormatPropertiesClass JfifFileFormatPropertiesClass;

#define TYPE_GDK_READER (gdk_reader_get_type ())
#define GDK_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDK_READER, GdkReader))
#define GDK_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDK_READER, GdkReaderClass))
#define IS_GDK_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDK_READER))
#define IS_GDK_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDK_READER))
#define GDK_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDK_READER, GdkReaderClass))

typedef struct _GdkReader GdkReader;
typedef struct _GdkReaderClass GdkReaderClass;

#define TYPE_JFIF_READER (jfif_reader_get_type ())
#define JFIF_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_JFIF_READER, JfifReader))
#define JFIF_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_JFIF_READER, JfifReaderClass))
#define IS_JFIF_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_JFIF_READER))
#define IS_JFIF_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_JFIF_READER))
#define JFIF_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_JFIF_READER, JfifReaderClass))

typedef struct _JfifReader JfifReader;
typedef struct _JfifReaderClass JfifReaderClass;

#define TYPE_JFIF_WRITER (jfif_writer_get_type ())
#define JFIF_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_JFIF_WRITER, JfifWriter))
#define JFIF_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_JFIF_WRITER, JfifWriterClass))
#define IS_JFIF_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_JFIF_WRITER))
#define IS_JFIF_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_JFIF_WRITER))
#define JFIF_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_JFIF_WRITER, JfifWriterClass))

typedef struct _JfifWriter JfifWriter;
typedef struct _JfifWriterClass JfifWriterClass;

#define TYPE_JFIF_METADATA_WRITER (jfif_metadata_writer_get_type ())
#define JFIF_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_JFIF_METADATA_WRITER, JfifMetadataWriter))
#define JFIF_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_JFIF_METADATA_WRITER, JfifMetadataWriterClass))
#define IS_JFIF_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_JFIF_METADATA_WRITER))
#define IS_JFIF_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_JFIF_METADATA_WRITER))
#define JFIF_METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_JFIF_METADATA_WRITER, JfifMetadataWriterClass))

typedef struct _JfifMetadataWriter JfifMetadataWriter;
typedef struct _JfifMetadataWriterClass JfifMetadataWriterClass;

#define TYPE_GDK_SNIFFER (gdk_sniffer_get_type ())
#define GDK_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDK_SNIFFER, GdkSniffer))
#define GDK_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDK_SNIFFER, GdkSnifferClass))
#define IS_GDK_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDK_SNIFFER))
#define IS_GDK_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDK_SNIFFER))
#define GDK_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDK_SNIFFER, GdkSnifferClass))

typedef struct _GdkSniffer GdkSniffer;
typedef struct _GdkSnifferClass GdkSnifferClass;

#define TYPE_JFIF_SNIFFER (jfif_sniffer_get_type ())
#define JFIF_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_JFIF_SNIFFER, JfifSniffer))
#define JFIF_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_JFIF_SNIFFER, JfifSnifferClass))
#define IS_JFIF_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_JFIF_SNIFFER))
#define IS_JFIF_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_JFIF_SNIFFER))
#define JFIF_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_JFIF_SNIFFER, JfifSnifferClass))

typedef struct _JfifSniffer JfifSniffer;
typedef struct _JfifSnifferClass JfifSnifferClass;
typedef struct _PhotoFileFormatPropertiesPrivate PhotoFileFormatPropertiesPrivate;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_PHOTO_FILE_FORMAT_FLAGS (photo_file_format_flags_get_type ())
typedef struct _JfifFileFormatPropertiesPrivate JfifFileFormatPropertiesPrivate;
#define _photo_file_format_properties_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_properties_unref (var), NULL)))
typedef struct _PhotoFileSnifferPrivate PhotoFileSnifferPrivate;

#define TYPE_DETECTED_PHOTO_INFORMATION (detected_photo_information_get_type ())
#define DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformation))
#define DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))
#define IS_DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DETECTED_PHOTO_INFORMATION))
#define IS_DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DETECTED_PHOTO_INFORMATION))
#define DETECTED_PHOTO_INFORMATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))

typedef struct _DetectedPhotoInformation DetectedPhotoInformation;
typedef struct _DetectedPhotoInformationClass DetectedPhotoInformationClass;
typedef struct _GdkSnifferPrivate GdkSnifferPrivate;
typedef struct _JfifSnifferPrivate JfifSnifferPrivate;
#define _detected_photo_information_unref0(var) ((var == NULL) ? NULL : (var = (detected_photo_information_unref (var), NULL)))
typedef struct _DetectedPhotoInformationPrivate DetectedPhotoInformationPrivate;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;
typedef struct _PhotoFileAdapterPrivate PhotoFileAdapterPrivate;
typedef struct _PhotoFileReaderPrivate PhotoFileReaderPrivate;
typedef struct _GdkReaderPrivate GdkReaderPrivate;
typedef struct _JfifReaderPrivate JfifReaderPrivate;
typedef struct _PhotoFileWriterPrivate PhotoFileWriterPrivate;

#define JPEG_TYPE_QUALITY (jpeg_quality_get_type ())
typedef struct _JfifWriterPrivate JfifWriterPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _PhotoFileMetadataWriterPrivate PhotoFileMetadataWriterPrivate;
typedef struct _JfifMetadataWriterPrivate JfifMetadataWriterPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define JPEG_TYPE_MARKER (jpeg_marker_get_type ())

typedef enum  {
	PHOTO_FILE_SNIFFER_OPTIONS_GET_ALL = 0x00000000,
	PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5 = 0x00000001
} PhotoFileSnifferOptions;

struct _PhotoFileFormatDriver {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileFormatDriverPrivate * priv;
};

struct _PhotoFileFormatDriverClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileFormatDriver *self);
	PhotoFileFormatProperties* (*get_properties) (PhotoFileFormatDriver* self);
	PhotoFileReader* (*create_reader) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoMetadata* (*create_metadata) (PhotoFileFormatDriver* self);
	gboolean (*can_write_image) (PhotoFileFormatDriver* self);
	gboolean (*can_write_metadata) (PhotoFileFormatDriver* self);
	PhotoFileWriter* (*create_writer) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoFileMetadataWriter* (*create_metadata_writer) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoFileSniffer* (*create_sniffer) (PhotoFileFormatDriver* self, GFile* file, PhotoFileSnifferOptions options);
};

struct _JfifFileFormatDriver {
	PhotoFileFormatDriver parent_instance;
	JfifFileFormatDriverPrivate * priv;
};

struct _JfifFileFormatDriverClass {
	PhotoFileFormatDriverClass parent_class;
};

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

typedef enum  {
	PHOTO_FILE_FORMAT_FLAGS_NONE = 0x00000000
} PhotoFileFormatFlags;

struct _PhotoFileFormatProperties {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileFormatPropertiesPrivate * priv;
};

struct _PhotoFileFormatPropertiesClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileFormatProperties *self);
	PhotoFileFormat (*get_file_format) (PhotoFileFormatProperties* self);
	PhotoFileFormatFlags (*get_flags) (PhotoFileFormatProperties* self);
	gboolean (*is_recognized_extension) (PhotoFileFormatProperties* self, const gchar* ext);
	gchar* (*get_default_extension) (PhotoFileFormatProperties* self);
	gchar** (*get_known_extensions) (PhotoFileFormatProperties* self, int* result_length1);
	gchar* (*get_default_mime_type) (PhotoFileFormatProperties* self);
	gchar** (*get_mime_types) (PhotoFileFormatProperties* self, int* result_length1);
	gchar* (*get_user_visible_name) (PhotoFileFormatProperties* self);
};

struct _JfifFileFormatProperties {
	PhotoFileFormatProperties parent_instance;
	JfifFileFormatPropertiesPrivate * priv;
};

struct _JfifFileFormatPropertiesClass {
	PhotoFileFormatPropertiesClass parent_class;
};

struct _PhotoFileSniffer {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileSnifferPrivate * priv;
	GFile* file;
	PhotoFileSnifferOptions options;
	gboolean calc_md5;
};

struct _PhotoFileSnifferClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileSniffer *self);
	DetectedPhotoInformation* (*sniff) (PhotoFileSniffer* self, gboolean* is_corrupted, GError** error);
};

struct _GdkSniffer {
	PhotoFileSniffer parent_instance;
	GdkSnifferPrivate * priv;
};

struct _GdkSnifferClass {
	PhotoFileSnifferClass parent_class;
};

struct _JfifSniffer {
	GdkSniffer parent_instance;
	JfifSnifferPrivate * priv;
};

struct _JfifSnifferClass {
	GdkSnifferClass parent_class;
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _DetectedPhotoInformation {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DetectedPhotoInformationPrivate * priv;
	PhotoFileFormat file_format;
	PhotoMetadata* metadata;
	gchar* md5;
	gchar* exif_md5;
	gchar* thumbnail_md5;
	gchar* format_name;
	Dimensions image_dim;
	GdkColorspace colorspace;
	gint channels;
	gint bits_per_channel;
};

struct _DetectedPhotoInformationClass {
	GTypeClass parent_class;
	void (*finalize) (DetectedPhotoInformation *self);
};

struct _PhotoFileAdapter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileAdapterPrivate * priv;
};

struct _PhotoFileAdapterClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileAdapter *self);
};

struct _PhotoFileReader {
	PhotoFileAdapter parent_instance;
	PhotoFileReaderPrivate * priv;
};

struct _PhotoFileReaderClass {
	PhotoFileAdapterClass parent_class;
	PhotoMetadata* (*read_metadata) (PhotoFileReader* self, GError** error);
	GdkPixbuf* (*unscaled_read) (PhotoFileReader* self, GError** error);
	GdkPixbuf* (*scaled_read) (PhotoFileReader* self, Dimensions* full, Dimensions* scaled, GError** error);
};

struct _GdkReader {
	PhotoFileReader parent_instance;
	GdkReaderPrivate * priv;
};

struct _GdkReaderClass {
	PhotoFileReaderClass parent_class;
};

struct _JfifReader {
	GdkReader parent_instance;
	JfifReaderPrivate * priv;
};

struct _JfifReaderClass {
	GdkReaderClass parent_class;
};

typedef enum  {
	JPEG_QUALITY_LOW = 50,
	JPEG_QUALITY_MEDIUM = 75,
	JPEG_QUALITY_HIGH = 90,
	JPEG_QUALITY_MAXIMUM = 100
} JpegQuality;

struct _PhotoFileWriter {
	PhotoFileAdapter parent_instance;
	PhotoFileWriterPrivate * priv;
};

struct _PhotoFileWriterClass {
	PhotoFileAdapterClass parent_class;
	void (*write) (PhotoFileWriter* self, GdkPixbuf* pixbuf, JpegQuality quality, GError** error);
};

struct _JfifWriter {
	PhotoFileWriter parent_instance;
	JfifWriterPrivate * priv;
};

struct _JfifWriterClass {
	PhotoFileWriterClass parent_class;
};

struct _PhotoFileMetadataWriter {
	PhotoFileAdapter parent_instance;
	PhotoFileMetadataWriterPrivate * priv;
};

struct _PhotoFileMetadataWriterClass {
	PhotoFileAdapterClass parent_class;
	void (*write_metadata) (PhotoFileMetadataWriter* self, PhotoMetadata* metadata, GError** error);
};

struct _JfifMetadataWriter {
	PhotoFileMetadataWriter parent_instance;
	JfifMetadataWriterPrivate * priv;
};

struct _JfifMetadataWriterClass {
	PhotoFileMetadataWriterClass parent_class;
};

typedef enum  {
	JPEG_MARKER_INVALID = 0x00,
	JPEG_MARKER_SOI = 0xD8,
	JPEG_MARKER_EOI = 0xD9,
	JPEG_MARKER_APP0 = 0xE0,
	JPEG_MARKER_APP1 = 0xE1
} JpegMarker;


static gpointer jfif_file_format_driver_parent_class = NULL;
static JfifFileFormatDriver* jfif_file_format_driver_instance;
static JfifFileFormatDriver* jfif_file_format_driver_instance = NULL;
static gpointer jfif_file_format_properties_parent_class = NULL;
static gchar** jfif_file_format_properties_KNOWN_EXTENSIONS;
static gint jfif_file_format_properties_KNOWN_EXTENSIONS_length1;
static gchar** jfif_file_format_properties_KNOWN_EXTENSIONS = NULL;
static gint jfif_file_format_properties_KNOWN_EXTENSIONS_length1 = 0;
static gint _jfif_file_format_properties_KNOWN_EXTENSIONS_size_ = 0;
static gchar** jfif_file_format_properties_KNOWN_MIME_TYPES;
static gint jfif_file_format_properties_KNOWN_MIME_TYPES_length1;
static gchar** jfif_file_format_properties_KNOWN_MIME_TYPES = NULL;
static gint jfif_file_format_properties_KNOWN_MIME_TYPES_length1 = 0;
static gint _jfif_file_format_properties_KNOWN_MIME_TYPES_size_ = 0;
static JfifFileFormatProperties* jfif_file_format_properties_instance;
static JfifFileFormatProperties* jfif_file_format_properties_instance = NULL;
static gpointer jfif_sniffer_parent_class = NULL;
static gpointer jfif_reader_parent_class = NULL;
static gpointer jfif_writer_parent_class = NULL;
static gpointer jfif_metadata_writer_parent_class = NULL;

gpointer photo_file_format_driver_ref (gpointer instance);
void photo_file_format_driver_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_driver (const gchar* name,
                                                 const gchar* nick,
                                                 const gchar* blurb,
                                                 GType object_type,
                                                 GParamFlags flags);
void value_set_photo_file_format_driver (GValue* value,
                                         gpointer v_object);
void value_take_photo_file_format_driver (GValue* value,
                                          gpointer v_object);
gpointer value_get_photo_file_format_driver (const GValue* value);
GType photo_file_format_driver_get_type (void) G_GNUC_CONST;
gpointer photo_file_format_properties_ref (gpointer instance);
void photo_file_format_properties_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_properties (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags);
void value_set_photo_file_format_properties (GValue* value,
                                             gpointer v_object);
void value_take_photo_file_format_properties (GValue* value,
                                              gpointer v_object);
gpointer value_get_photo_file_format_properties (const GValue* value);
GType photo_file_format_properties_get_type (void) G_GNUC_CONST;
gpointer photo_file_adapter_ref (gpointer instance);
void photo_file_adapter_unref (gpointer instance);
GParamSpec* param_spec_photo_file_adapter (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
void value_set_photo_file_adapter (GValue* value,
                                   gpointer v_object);
void value_take_photo_file_adapter (GValue* value,
                                    gpointer v_object);
gpointer value_get_photo_file_adapter (const GValue* value);
GType photo_file_adapter_get_type (void) G_GNUC_CONST;
GType photo_file_reader_get_type (void) G_GNUC_CONST;
gpointer media_metadata_ref (gpointer instance);
void media_metadata_unref (gpointer instance);
GParamSpec* param_spec_media_metadata (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
void value_set_media_metadata (GValue* value,
                               gpointer v_object);
void value_take_media_metadata (GValue* value,
                                gpointer v_object);
gpointer value_get_media_metadata (const GValue* value);
GType media_metadata_get_type (void) G_GNUC_CONST;
GType photo_metadata_get_type (void) G_GNUC_CONST;
GType photo_file_writer_get_type (void) G_GNUC_CONST;
GType photo_file_metadata_writer_get_type (void) G_GNUC_CONST;
GType photo_file_sniffer_options_get_type (void) G_GNUC_CONST;
gpointer photo_file_sniffer_ref (gpointer instance);
void photo_file_sniffer_unref (gpointer instance);
GParamSpec* param_spec_photo_file_sniffer (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
void value_set_photo_file_sniffer (GValue* value,
                                   gpointer v_object);
void value_take_photo_file_sniffer (GValue* value,
                                    gpointer v_object);
gpointer value_get_photo_file_sniffer (const GValue* value);
GType photo_file_sniffer_get_type (void) G_GNUC_CONST;
GType jfif_file_format_driver_get_type (void) G_GNUC_CONST;
void jfif_file_format_driver_init (void);
JfifFileFormatDriver* jfif_file_format_driver_new (void);
JfifFileFormatDriver* jfif_file_format_driver_construct (GType object_type);
void jfif_file_format_properties_init (void);
JfifFileFormatDriver* jfif_file_format_driver_get_instance (void);
static PhotoFileFormatProperties* jfif_file_format_driver_real_get_properties (PhotoFileFormatDriver* base);
GType jfif_file_format_properties_get_type (void) G_GNUC_CONST;
JfifFileFormatProperties* jfif_file_format_properties_get_instance (void);
static PhotoFileReader* jfif_file_format_driver_real_create_reader (PhotoFileFormatDriver* base,
                                                             const gchar* filepath);
JfifReader* jfif_reader_new (const gchar* filepath);
JfifReader* jfif_reader_construct (GType object_type,
                                   const gchar* filepath);
GType gdk_reader_get_type (void) G_GNUC_CONST;
GType jfif_reader_get_type (void) G_GNUC_CONST;
static PhotoMetadata* jfif_file_format_driver_real_create_metadata (PhotoFileFormatDriver* base);
PhotoMetadata* photo_metadata_new (void);
PhotoMetadata* photo_metadata_construct (GType object_type);
static gboolean jfif_file_format_driver_real_can_write_image (PhotoFileFormatDriver* base);
static gboolean jfif_file_format_driver_real_can_write_metadata (PhotoFileFormatDriver* base);
static PhotoFileWriter* jfif_file_format_driver_real_create_writer (PhotoFileFormatDriver* base,
                                                             const gchar* filepath);
JfifWriter* jfif_writer_new (const gchar* filepath);
JfifWriter* jfif_writer_construct (GType object_type,
                                   const gchar* filepath);
GType jfif_writer_get_type (void) G_GNUC_CONST;
static PhotoFileMetadataWriter* jfif_file_format_driver_real_create_metadata_writer (PhotoFileFormatDriver* base,
                                                                              const gchar* filepath);
JfifMetadataWriter* jfif_metadata_writer_new (const gchar* filepath);
JfifMetadataWriter* jfif_metadata_writer_construct (GType object_type,
                                                    const gchar* filepath);
GType jfif_metadata_writer_get_type (void) G_GNUC_CONST;
static PhotoFileSniffer* jfif_file_format_driver_real_create_sniffer (PhotoFileFormatDriver* base,
                                                               GFile* file,
                                                               PhotoFileSnifferOptions options);
JfifSniffer* jfif_sniffer_new (GFile* file,
                               PhotoFileSnifferOptions options);
JfifSniffer* jfif_sniffer_construct (GType object_type,
                                     GFile* file,
                                     PhotoFileSnifferOptions options);
GType gdk_sniffer_get_type (void) G_GNUC_CONST;
GType jfif_sniffer_get_type (void) G_GNUC_CONST;
PhotoFileFormatDriver* photo_file_format_driver_construct (GType object_type);
static void jfif_file_format_driver_finalize (PhotoFileFormatDriver * obj);
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType photo_file_format_flags_get_type (void) G_GNUC_CONST;
JfifFileFormatProperties* jfif_file_format_properties_new (void);
JfifFileFormatProperties* jfif_file_format_properties_construct (GType object_type);
static PhotoFileFormat jfif_file_format_properties_real_get_file_format (PhotoFileFormatProperties* base);
static PhotoFileFormatFlags jfif_file_format_properties_real_get_flags (PhotoFileFormatProperties* base);
static gchar* jfif_file_format_properties_real_get_default_extension (PhotoFileFormatProperties* base);
static gchar* jfif_file_format_properties_real_get_user_visible_name (PhotoFileFormatProperties* base);
static gchar** jfif_file_format_properties_real_get_known_extensions (PhotoFileFormatProperties* base,
                                                               int* result_length1);
static gchar** _vala_array_dup6 (gchar** self,
                          int length);
static gchar* jfif_file_format_properties_real_get_default_mime_type (PhotoFileFormatProperties* base);
static gchar** jfif_file_format_properties_real_get_mime_types (PhotoFileFormatProperties* base,
                                                         int* result_length1);
static gchar** _vala_array_dup7 (gchar** self,
                          int length);
PhotoFileFormatProperties* photo_file_format_properties_construct (GType object_type);
static void jfif_file_format_properties_finalize (PhotoFileFormatProperties * obj);
gpointer detected_photo_information_ref (gpointer instance);
void detected_photo_information_unref (gpointer instance);
GParamSpec* param_spec_detected_photo_information (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags);
void value_set_detected_photo_information (GValue* value,
                                           gpointer v_object);
void value_take_detected_photo_information (GValue* value,
                                            gpointer v_object);
gpointer value_get_detected_photo_information (const GValue* value);
GType detected_photo_information_get_type (void) G_GNUC_CONST;
GdkSniffer* gdk_sniffer_construct (GType object_type,
                                   GFile* file,
                                   PhotoFileSnifferOptions options);
static DetectedPhotoInformation* jfif_sniffer_real_sniff (PhotoFileSniffer* base,
                                                   gboolean* is_corrupted,
                                                   GError** error);
gboolean jpeg_is_jpeg (GFile* file,
                       GError** error);
DetectedPhotoInformation* photo_file_sniffer_sniff (PhotoFileSniffer* self,
                                                    gboolean* is_corrupted,
                                                    GError** error);
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
GdkReader* gdk_reader_construct (GType object_type,
                                 const gchar* filepath,
                                 PhotoFileFormat file_format);
GType jpeg_quality_get_type (void) G_GNUC_CONST;
PhotoFileWriter* photo_file_writer_construct (GType object_type,
                                              const gchar* filepath,
                                              PhotoFileFormat file_format);
static void jfif_writer_real_write (PhotoFileWriter* base,
                             GdkPixbuf* pixbuf,
                             JpegQuality quality,
                             GError** error);
gchar* photo_file_adapter_get_filepath (PhotoFileAdapter* self);
gchar* jpeg_quality_get_pct_text (JpegQuality self);
PhotoFileMetadataWriter* photo_file_metadata_writer_construct (GType object_type,
                                                               const gchar* filepath,
                                                               PhotoFileFormat file_format);
static void jfif_metadata_writer_real_write_metadata (PhotoFileMetadataWriter* base,
                                               PhotoMetadata* metadata,
                                               GError** error);
void photo_metadata_write_to_file (PhotoMetadata* self,
                                   GFile* file,
                                   GError** error);
GFile* photo_file_adapter_get_file (PhotoFileAdapter* self);
#define JPEG_MARKER_PREFIX ((guint8) 0xFF)
GType jpeg_marker_get_type (void) G_GNUC_CONST;
guint8 jpeg_marker_get_byte (JpegMarker self);
gint jpeg_quality_get_pct (JpegQuality self);
JpegQuality* jpeg_quality_get_all (int* result_length1);
gchar* jpeg_quality_to_string (JpegQuality self);
gboolean jpeg_is_jpeg_stream (GInputStream* ins,
                              GError** error);
gint jpeg_read_marker (GInputStream* fins,
                       JpegMarker* marker,
                       GError** error);
gboolean jpeg_is_jpeg_bytes (GBytes* bytes,
                             GError** error);


void
jfif_file_format_driver_init (void)
{
	JfifFileFormatDriver* _tmp0_;
#line 11 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_driver_new ();
#line 11 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_photo_file_format_driver_unref0 (jfif_file_format_driver_instance);
#line 11 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_driver_instance = _tmp0_;
#line 12 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_properties_init ();
#line 695 "JfifSupport.c"
}


static gpointer
_photo_file_format_driver_ref0 (gpointer self)
{
#line 16 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self ? photo_file_format_driver_ref (self) : NULL;
#line 704 "JfifSupport.c"
}


JfifFileFormatDriver*
jfif_file_format_driver_get_instance (void)
{
	JfifFileFormatDriver* result = NULL;
	JfifFileFormatDriver* _tmp0_;
	JfifFileFormatDriver* _tmp1_;
#line 16 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_driver_instance;
#line 16 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = _photo_file_format_driver_ref0 (_tmp0_);
#line 16 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp1_;
#line 16 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 722 "JfifSupport.c"
}


static PhotoFileFormatProperties*
jfif_file_format_driver_real_get_properties (PhotoFileFormatDriver* base)
{
	JfifFileFormatDriver * self;
	PhotoFileFormatProperties* result = NULL;
	JfifFileFormatProperties* _tmp0_;
#line 19 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 20 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_properties_get_instance ();
#line 20 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties);
#line 20 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 740 "JfifSupport.c"
}


static PhotoFileReader*
jfif_file_format_driver_real_create_reader (PhotoFileFormatDriver* base,
                                            const gchar* filepath)
{
	JfifFileFormatDriver * self;
	PhotoFileReader* result = NULL;
	JfifReader* _tmp0_;
#line 23 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 23 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 24 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_reader_new (filepath);
#line 24 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_READER, PhotoFileReader);
#line 24 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 761 "JfifSupport.c"
}


static PhotoMetadata*
jfif_file_format_driver_real_create_metadata (PhotoFileFormatDriver* base)
{
	JfifFileFormatDriver * self;
	PhotoMetadata* result = NULL;
	PhotoMetadata* _tmp0_;
#line 27 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 28 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = photo_metadata_new ();
#line 28 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp0_;
#line 28 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 779 "JfifSupport.c"
}


static gboolean
jfif_file_format_driver_real_can_write_image (PhotoFileFormatDriver* base)
{
	JfifFileFormatDriver * self;
	gboolean result = FALSE;
#line 31 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 32 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = TRUE;
#line 32 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 794 "JfifSupport.c"
}


static gboolean
jfif_file_format_driver_real_can_write_metadata (PhotoFileFormatDriver* base)
{
	JfifFileFormatDriver * self;
	gboolean result = FALSE;
#line 35 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 36 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = TRUE;
#line 36 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 809 "JfifSupport.c"
}


static PhotoFileWriter*
jfif_file_format_driver_real_create_writer (PhotoFileFormatDriver* base,
                                            const gchar* filepath)
{
	JfifFileFormatDriver * self;
	PhotoFileWriter* result = NULL;
	JfifWriter* _tmp0_;
#line 39 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 39 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 40 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_writer_new (filepath);
#line 40 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_WRITER, PhotoFileWriter);
#line 40 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 830 "JfifSupport.c"
}


static PhotoFileMetadataWriter*
jfif_file_format_driver_real_create_metadata_writer (PhotoFileFormatDriver* base,
                                                     const gchar* filepath)
{
	JfifFileFormatDriver * self;
	PhotoFileMetadataWriter* result = NULL;
	JfifMetadataWriter* _tmp0_;
#line 43 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 43 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 44 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_metadata_writer_new (filepath);
#line 44 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriter);
#line 44 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 851 "JfifSupport.c"
}


static PhotoFileSniffer*
jfif_file_format_driver_real_create_sniffer (PhotoFileFormatDriver* base,
                                             GFile* file,
                                             PhotoFileSnifferOptions options)
{
	JfifFileFormatDriver * self;
	PhotoFileSniffer* result = NULL;
	JfifSniffer* _tmp0_;
#line 47 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 47 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 48 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_sniffer_new (file, options);
#line 48 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer);
#line 48 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 873 "JfifSupport.c"
}


JfifFileFormatDriver*
jfif_file_format_driver_construct (GType object_type)
{
	JfifFileFormatDriver* self = NULL;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = (JfifFileFormatDriver*) photo_file_format_driver_construct (object_type);
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self;
#line 885 "JfifSupport.c"
}


JfifFileFormatDriver*
jfif_file_format_driver_new (void)
{
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return jfif_file_format_driver_construct (TYPE_JFIF_FILE_FORMAT_DRIVER);
#line 894 "JfifSupport.c"
}


static void
jfif_file_format_driver_class_init (JfifFileFormatDriverClass * klass)
{
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_driver_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->finalize = jfif_file_format_driver_finalize;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->get_properties = (PhotoFileFormatProperties* (*) (PhotoFileFormatDriver *)) jfif_file_format_driver_real_get_properties;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_reader = (PhotoFileReader* (*) (PhotoFileFormatDriver *, const gchar*)) jfif_file_format_driver_real_create_reader;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_metadata = (PhotoMetadata* (*) (PhotoFileFormatDriver *)) jfif_file_format_driver_real_create_metadata;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->can_write_image = (gboolean (*) (PhotoFileFormatDriver *)) jfif_file_format_driver_real_can_write_image;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->can_write_metadata = (gboolean (*) (PhotoFileFormatDriver *)) jfif_file_format_driver_real_can_write_metadata;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_writer = (PhotoFileWriter* (*) (PhotoFileFormatDriver *, const gchar*)) jfif_file_format_driver_real_create_writer;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_metadata_writer = (PhotoFileMetadataWriter* (*) (PhotoFileFormatDriver *, const gchar*)) jfif_file_format_driver_real_create_metadata_writer;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_sniffer = (PhotoFileSniffer* (*) (PhotoFileFormatDriver *, GFile*, PhotoFileSnifferOptions)) jfif_file_format_driver_real_create_sniffer;
#line 921 "JfifSupport.c"
}


static void
jfif_file_format_driver_instance_init (JfifFileFormatDriver * self)
{
}


static void
jfif_file_format_driver_finalize (PhotoFileFormatDriver * obj)
{
	JfifFileFormatDriver * self;
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_JFIF_FILE_FORMAT_DRIVER, JfifFileFormatDriver);
#line 7 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	PHOTO_FILE_FORMAT_DRIVER_CLASS (jfif_file_format_driver_parent_class)->finalize (obj);
#line 939 "JfifSupport.c"
}


GType
jfif_file_format_driver_get_type (void)
{
	static volatile gsize jfif_file_format_driver_type_id__volatile = 0;
	if (g_once_init_enter (&jfif_file_format_driver_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (JfifFileFormatDriverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) jfif_file_format_driver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (JfifFileFormatDriver), 0, (GInstanceInitFunc) jfif_file_format_driver_instance_init, NULL };
		GType jfif_file_format_driver_type_id;
		jfif_file_format_driver_type_id = g_type_register_static (TYPE_PHOTO_FILE_FORMAT_DRIVER, "JfifFileFormatDriver", &g_define_type_info, 0);
		g_once_init_leave (&jfif_file_format_driver_type_id__volatile, jfif_file_format_driver_type_id);
	}
	return jfif_file_format_driver_type_id__volatile;
}


void
jfif_file_format_properties_init (void)
{
	JfifFileFormatProperties* _tmp0_;
#line 64 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_properties_new ();
#line 64 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_photo_file_format_properties_unref0 (jfif_file_format_properties_instance);
#line 64 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_properties_instance = _tmp0_;
#line 967 "JfifSupport.c"
}


static gpointer
_photo_file_format_properties_ref0 (gpointer self)
{
#line 68 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self ? photo_file_format_properties_ref (self) : NULL;
#line 976 "JfifSupport.c"
}


JfifFileFormatProperties*
jfif_file_format_properties_get_instance (void)
{
	JfifFileFormatProperties* result = NULL;
	JfifFileFormatProperties* _tmp0_;
	JfifFileFormatProperties* _tmp1_;
#line 68 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_properties_instance;
#line 68 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = _photo_file_format_properties_ref0 (_tmp0_);
#line 68 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp1_;
#line 68 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 994 "JfifSupport.c"
}


static PhotoFileFormat
jfif_file_format_properties_real_get_file_format (PhotoFileFormatProperties* base)
{
	JfifFileFormatProperties * self;
	PhotoFileFormat result = 0;
#line 71 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 72 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = PHOTO_FILE_FORMAT_JFIF;
#line 72 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1009 "JfifSupport.c"
}


static PhotoFileFormatFlags
jfif_file_format_properties_real_get_flags (PhotoFileFormatProperties* base)
{
	JfifFileFormatProperties * self;
	PhotoFileFormatFlags result = 0;
#line 75 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 76 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = PHOTO_FILE_FORMAT_FLAGS_NONE;
#line 76 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1024 "JfifSupport.c"
}


static gchar*
jfif_file_format_properties_real_get_default_extension (PhotoFileFormatProperties* base)
{
	JfifFileFormatProperties * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 79 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 80 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = g_strdup ("jpg");
#line 80 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp0_;
#line 80 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1042 "JfifSupport.c"
}


static gchar*
jfif_file_format_properties_real_get_user_visible_name (PhotoFileFormatProperties* base)
{
	JfifFileFormatProperties * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 83 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 84 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = g_strdup (_ ("JPEG"));
#line 84 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp0_;
#line 84 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1060 "JfifSupport.c"
}


static gchar**
_vala_array_dup6 (gchar** self,
                  int length)
{
	gchar** result;
	int i;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = g_new0 (gchar*, length + 1);
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	for (i = 0; i < length; i++) {
#line 1074 "JfifSupport.c"
		gchar* _tmp0_;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp0_ = g_strdup (self[i]);
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		result[i] = _tmp0_;
#line 1080 "JfifSupport.c"
	}
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1084 "JfifSupport.c"
}


static gchar**
jfif_file_format_properties_real_get_known_extensions (PhotoFileFormatProperties* base,
                                                       int* result_length1)
{
	JfifFileFormatProperties * self;
	gchar** result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar** _tmp2_;
	gint _tmp2__length1;
#line 87 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_properties_KNOWN_EXTENSIONS;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0__length1 = jfif_file_format_properties_KNOWN_EXTENSIONS_length1;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup6 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1__length1 = _tmp0__length1;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2_ = _tmp1_;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2__length1 = _tmp1__length1;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (result_length1) {
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		*result_length1 = _tmp2__length1;
#line 1118 "JfifSupport.c"
	}
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp2_;
#line 88 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1124 "JfifSupport.c"
}


static gchar*
jfif_file_format_properties_real_get_default_mime_type (PhotoFileFormatProperties* base)
{
	JfifFileFormatProperties * self;
	gchar* result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 91 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 92 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_properties_KNOWN_MIME_TYPES;
#line 92 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0__length1 = jfif_file_format_properties_KNOWN_MIME_TYPES_length1;
#line 92 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = _tmp0_[0];
#line 92 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 92 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp2_;
#line 92 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1151 "JfifSupport.c"
}


static gchar**
_vala_array_dup7 (gchar** self,
                  int length)
{
	gchar** result;
	int i;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = g_new0 (gchar*, length + 1);
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	for (i = 0; i < length; i++) {
#line 1165 "JfifSupport.c"
		gchar* _tmp0_;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp0_ = g_strdup (self[i]);
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		result[i] = _tmp0_;
#line 1171 "JfifSupport.c"
	}
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1175 "JfifSupport.c"
}


static gchar**
jfif_file_format_properties_real_get_mime_types (PhotoFileFormatProperties* base,
                                                 int* result_length1)
{
	JfifFileFormatProperties * self;
	gchar** result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar** _tmp2_;
	gint _tmp2__length1;
#line 95 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jfif_file_format_properties_KNOWN_MIME_TYPES;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0__length1 = jfif_file_format_properties_KNOWN_MIME_TYPES_length1;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup7 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1__length1 = _tmp0__length1;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2_ = _tmp1_;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2__length1 = _tmp1__length1;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (result_length1) {
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		*result_length1 = _tmp2__length1;
#line 1209 "JfifSupport.c"
	}
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp2_;
#line 96 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1215 "JfifSupport.c"
}


JfifFileFormatProperties*
jfif_file_format_properties_construct (GType object_type)
{
	JfifFileFormatProperties* self = NULL;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = (JfifFileFormatProperties*) photo_file_format_properties_construct (object_type);
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self;
#line 1227 "JfifSupport.c"
}


JfifFileFormatProperties*
jfif_file_format_properties_new (void)
{
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return jfif_file_format_properties_construct (TYPE_JFIF_FILE_FORMAT_PROPERTIES);
#line 1236 "JfifSupport.c"
}


static void
jfif_file_format_properties_class_init (JfifFileFormatPropertiesClass * klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_properties_parent_class = g_type_class_peek_parent (klass);
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->finalize = jfif_file_format_properties_finalize;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_file_format = (PhotoFileFormat (*) (PhotoFileFormatProperties *)) jfif_file_format_properties_real_get_file_format;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_flags = (PhotoFileFormatFlags (*) (PhotoFileFormatProperties *)) jfif_file_format_properties_real_get_flags;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_default_extension = (gchar* (*) (PhotoFileFormatProperties *)) jfif_file_format_properties_real_get_default_extension;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_user_visible_name = (gchar* (*) (PhotoFileFormatProperties *)) jfif_file_format_properties_real_get_user_visible_name;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_known_extensions = (gchar** (*) (PhotoFileFormatProperties *, int*)) jfif_file_format_properties_real_get_known_extensions;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_default_mime_type = (gchar* (*) (PhotoFileFormatProperties *)) jfif_file_format_properties_real_get_default_mime_type;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_mime_types = (gchar** (*) (PhotoFileFormatProperties *, int*)) jfif_file_format_properties_real_get_mime_types;
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = g_strdup ("jpg");
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = g_strdup ("jpeg");
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2_ = g_strdup ("jpe");
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp3_ = g_strdup ("thm");
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp4_ = g_new0 (gchar*, 4 + 1);
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp4_[0] = _tmp0_;
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp4_[1] = _tmp1_;
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp4_[2] = _tmp2_;
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp4_[3] = _tmp3_;
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_properties_KNOWN_EXTENSIONS = _tmp4_;
#line 53 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_properties_KNOWN_EXTENSIONS_length1 = 4;
#line 57 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp5_ = g_strdup ("image/jpeg");
#line 57 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp6_ = g_new0 (gchar*, 1 + 1);
#line 57 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp6_[0] = _tmp5_;
#line 57 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_properties_KNOWN_MIME_TYPES = _tmp6_;
#line 57 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_file_format_properties_KNOWN_MIME_TYPES_length1 = 1;
#line 1300 "JfifSupport.c"
}


static void
jfif_file_format_properties_instance_init (JfifFileFormatProperties * self)
{
}


static void
jfif_file_format_properties_finalize (PhotoFileFormatProperties * obj)
{
	JfifFileFormatProperties * self;
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_JFIF_FILE_FORMAT_PROPERTIES, JfifFileFormatProperties);
#line 52 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	PHOTO_FILE_FORMAT_PROPERTIES_CLASS (jfif_file_format_properties_parent_class)->finalize (obj);
#line 1318 "JfifSupport.c"
}


GType
jfif_file_format_properties_get_type (void)
{
	static volatile gsize jfif_file_format_properties_type_id__volatile = 0;
	if (g_once_init_enter (&jfif_file_format_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (JfifFileFormatPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) jfif_file_format_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (JfifFileFormatProperties), 0, (GInstanceInitFunc) jfif_file_format_properties_instance_init, NULL };
		GType jfif_file_format_properties_type_id;
		jfif_file_format_properties_type_id = g_type_register_static (TYPE_PHOTO_FILE_FORMAT_PROPERTIES, "JfifFileFormatProperties", &g_define_type_info, 0);
		g_once_init_leave (&jfif_file_format_properties_type_id__volatile, jfif_file_format_properties_type_id);
	}
	return jfif_file_format_properties_type_id__volatile;
}


JfifSniffer*
jfif_sniffer_construct (GType object_type,
                        GFile* file,
                        PhotoFileSnifferOptions options)
{
	JfifSniffer* self = NULL;
#line 101 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 102 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = (JfifSniffer*) gdk_sniffer_construct (object_type, file, options);
#line 101 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self;
#line 1348 "JfifSupport.c"
}


JfifSniffer*
jfif_sniffer_new (GFile* file,
                  PhotoFileSnifferOptions options)
{
#line 101 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return jfif_sniffer_construct (TYPE_JFIF_SNIFFER, file, options);
#line 1358 "JfifSupport.c"
}


static gpointer
_detected_photo_information_ref0 (gpointer self)
{
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self ? detected_photo_information_ref (self) : NULL;
#line 1367 "JfifSupport.c"
}


static DetectedPhotoInformation*
jfif_sniffer_real_sniff (PhotoFileSniffer* base,
                         gboolean* is_corrupted,
                         GError** error)
{
	JfifSniffer * self;
	gboolean _vala_is_corrupted = FALSE;
	DetectedPhotoInformation* result = NULL;
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_;
	DetectedPhotoInformation* detected = NULL;
	gboolean _tmp2_ = FALSE;
	DetectedPhotoInformation* _tmp3_;
	DetectedPhotoInformation* _tmp4_;
	DetectedPhotoInformation* _tmp5_ = NULL;
	DetectedPhotoInformation* _tmp6_;
	PhotoFileFormat _tmp7_;
	DetectedPhotoInformation* _tmp9_;
	GError * _inner_error_ = NULL;
#line 105 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_SNIFFER, JfifSniffer);
#line 107 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_vala_is_corrupted = FALSE;
#line 109 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer)->file;
#line 109 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = jpeg_is_jpeg (_tmp1_, &_inner_error_);
#line 109 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 109 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return NULL;
#line 1404 "JfifSupport.c"
	}
#line 109 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (!_tmp0_) {
#line 110 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		result = NULL;
#line 110 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		if (is_corrupted) {
#line 110 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			*is_corrupted = _vala_is_corrupted;
#line 1414 "JfifSupport.c"
		}
#line 110 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return result;
#line 1418 "JfifSupport.c"
	}
#line 112 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp3_ = PHOTO_FILE_SNIFFER_CLASS (jfif_sniffer_parent_class)->sniff (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_GDK_SNIFFER, GdkSniffer), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer), &_tmp2_, &_inner_error_);
#line 112 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_vala_is_corrupted = _tmp2_;
#line 112 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	detected = _tmp3_;
#line 112 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 112 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 112 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return NULL;
#line 1432 "JfifSupport.c"
	}
#line 113 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp4_ = detected;
#line 113 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (_tmp4_ == NULL) {
#line 114 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		result = NULL;
#line 114 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_detected_photo_information_unref0 (detected);
#line 114 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		if (is_corrupted) {
#line 114 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			*is_corrupted = _vala_is_corrupted;
#line 1446 "JfifSupport.c"
		}
#line 114 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return result;
#line 1450 "JfifSupport.c"
	}
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp6_ = detected;
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp7_ = _tmp6_->file_format;
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (_tmp7_ == PHOTO_FILE_FORMAT_JFIF) {
#line 1458 "JfifSupport.c"
		DetectedPhotoInformation* _tmp8_;
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp8_ = detected;
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp5_ = _tmp8_;
#line 1464 "JfifSupport.c"
	} else {
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp5_ = NULL;
#line 1468 "JfifSupport.c"
	}
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp9_ = _detected_photo_information_ref0 (_tmp5_);
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp9_;
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_detected_photo_information_unref0 (detected);
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (is_corrupted) {
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		*is_corrupted = _vala_is_corrupted;
#line 1480 "JfifSupport.c"
	}
#line 116 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1484 "JfifSupport.c"
}


static void
jfif_sniffer_class_init (JfifSnifferClass * klass)
{
#line 100 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_sniffer_parent_class = g_type_class_peek_parent (klass);
#line 100 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileSnifferClass *) klass)->sniff = (DetectedPhotoInformation* (*) (PhotoFileSniffer *, gboolean*, GError**)) jfif_sniffer_real_sniff;
#line 1495 "JfifSupport.c"
}


static void
jfif_sniffer_instance_init (JfifSniffer * self)
{
}


GType
jfif_sniffer_get_type (void)
{
	static volatile gsize jfif_sniffer_type_id__volatile = 0;
	if (g_once_init_enter (&jfif_sniffer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (JfifSnifferClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) jfif_sniffer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (JfifSniffer), 0, (GInstanceInitFunc) jfif_sniffer_instance_init, NULL };
		GType jfif_sniffer_type_id;
		jfif_sniffer_type_id = g_type_register_static (TYPE_GDK_SNIFFER, "JfifSniffer", &g_define_type_info, 0);
		g_once_init_leave (&jfif_sniffer_type_id__volatile, jfif_sniffer_type_id);
	}
	return jfif_sniffer_type_id__volatile;
}


JfifReader*
jfif_reader_construct (GType object_type,
                       const gchar* filepath)
{
	JfifReader* self = NULL;
#line 121 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 122 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = (JfifReader*) gdk_reader_construct (object_type, filepath, PHOTO_FILE_FORMAT_JFIF);
#line 121 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self;
#line 1530 "JfifSupport.c"
}


JfifReader*
jfif_reader_new (const gchar* filepath)
{
#line 121 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return jfif_reader_construct (TYPE_JFIF_READER, filepath);
#line 1539 "JfifSupport.c"
}


static void
jfif_reader_class_init (JfifReaderClass * klass)
{
#line 120 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_reader_parent_class = g_type_class_peek_parent (klass);
#line 1548 "JfifSupport.c"
}


static void
jfif_reader_instance_init (JfifReader * self)
{
}


GType
jfif_reader_get_type (void)
{
	static volatile gsize jfif_reader_type_id__volatile = 0;
	if (g_once_init_enter (&jfif_reader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (JfifReaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) jfif_reader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (JfifReader), 0, (GInstanceInitFunc) jfif_reader_instance_init, NULL };
		GType jfif_reader_type_id;
		jfif_reader_type_id = g_type_register_static (TYPE_GDK_READER, "JfifReader", &g_define_type_info, 0);
		g_once_init_leave (&jfif_reader_type_id__volatile, jfif_reader_type_id);
	}
	return jfif_reader_type_id__volatile;
}


JfifWriter*
jfif_writer_construct (GType object_type,
                       const gchar* filepath)
{
	JfifWriter* self = NULL;
#line 127 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 128 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = (JfifWriter*) photo_file_writer_construct (object_type, filepath, PHOTO_FILE_FORMAT_JFIF);
#line 127 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self;
#line 1583 "JfifSupport.c"
}


JfifWriter*
jfif_writer_new (const gchar* filepath)
{
#line 127 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return jfif_writer_construct (TYPE_JFIF_WRITER, filepath);
#line 1592 "JfifSupport.c"
}


static void
jfif_writer_real_write (PhotoFileWriter* base,
                        GdkPixbuf* pixbuf,
                        JpegQuality quality,
                        GError** error)
{
	JfifWriter * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 131 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_WRITER, JfifWriter);
#line 131 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_if_fail (GDK_IS_PIXBUF (pixbuf));
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = _tmp0_;
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2_ = jpeg_quality_get_pct_text (quality);
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp3_ = _tmp2_;
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	gdk_pixbuf_save (pixbuf, _tmp1_, "jpeg", &_inner_error_, "quality", _tmp3_, NULL);
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_g_free0 (_tmp3_);
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_g_free0 (_tmp1_);
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 132 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return;
#line 1632 "JfifSupport.c"
	}
}


static void
jfif_writer_class_init (JfifWriterClass * klass)
{
#line 126 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_writer_parent_class = g_type_class_peek_parent (klass);
#line 126 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileWriterClass *) klass)->write = (void (*) (PhotoFileWriter *, GdkPixbuf*, JpegQuality, GError**)) jfif_writer_real_write;
#line 1644 "JfifSupport.c"
}


static void
jfif_writer_instance_init (JfifWriter * self)
{
}


GType
jfif_writer_get_type (void)
{
	static volatile gsize jfif_writer_type_id__volatile = 0;
	if (g_once_init_enter (&jfif_writer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (JfifWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) jfif_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (JfifWriter), 0, (GInstanceInitFunc) jfif_writer_instance_init, NULL };
		GType jfif_writer_type_id;
		jfif_writer_type_id = g_type_register_static (TYPE_PHOTO_FILE_WRITER, "JfifWriter", &g_define_type_info, 0);
		g_once_init_leave (&jfif_writer_type_id__volatile, jfif_writer_type_id);
	}
	return jfif_writer_type_id__volatile;
}


JfifMetadataWriter*
jfif_metadata_writer_construct (GType object_type,
                                const gchar* filepath)
{
	JfifMetadataWriter* self = NULL;
#line 137 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 138 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = (JfifMetadataWriter*) photo_file_metadata_writer_construct (object_type, filepath, PHOTO_FILE_FORMAT_JFIF);
#line 137 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return self;
#line 1679 "JfifSupport.c"
}


JfifMetadataWriter*
jfif_metadata_writer_new (const gchar* filepath)
{
#line 137 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return jfif_metadata_writer_construct (TYPE_JFIF_METADATA_WRITER, filepath);
#line 1688 "JfifSupport.c"
}


static void
jfif_metadata_writer_real_write_metadata (PhotoFileMetadataWriter* base,
                                          PhotoMetadata* metadata,
                                          GError** error)
{
	JfifMetadataWriter * self;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GError * _inner_error_ = NULL;
#line 141 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_JFIF_METADATA_WRITER, JfifMetadataWriter);
#line 141 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_if_fail (IS_PHOTO_METADATA (metadata));
#line 142 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 142 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = _tmp0_;
#line 142 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	photo_metadata_write_to_file (metadata, _tmp1_, &_inner_error_);
#line 142 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_g_object_unref0 (_tmp1_);
#line 142 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 142 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 142 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return;
#line 1719 "JfifSupport.c"
	}
}


static void
jfif_metadata_writer_class_init (JfifMetadataWriterClass * klass)
{
#line 136 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	jfif_metadata_writer_parent_class = g_type_class_peek_parent (klass);
#line 136 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	((PhotoFileMetadataWriterClass *) klass)->write_metadata = (void (*) (PhotoFileMetadataWriter *, PhotoMetadata*, GError**)) jfif_metadata_writer_real_write_metadata;
#line 1731 "JfifSupport.c"
}


static void
jfif_metadata_writer_instance_init (JfifMetadataWriter * self)
{
}


GType
jfif_metadata_writer_get_type (void)
{
	static volatile gsize jfif_metadata_writer_type_id__volatile = 0;
	if (g_once_init_enter (&jfif_metadata_writer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (JfifMetadataWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) jfif_metadata_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (JfifMetadataWriter), 0, (GInstanceInitFunc) jfif_metadata_writer_instance_init, NULL };
		GType jfif_metadata_writer_type_id;
		jfif_metadata_writer_type_id = g_type_register_static (TYPE_PHOTO_FILE_METADATA_WRITER, "JfifMetadataWriter", &g_define_type_info, 0);
		g_once_init_leave (&jfif_metadata_writer_type_id__volatile, jfif_metadata_writer_type_id);
	}
	return jfif_metadata_writer_type_id__volatile;
}


guint8
jpeg_marker_get_byte (JpegMarker self)
{
	guint8 result = 0U;
#line 160 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = (guint8) self;
#line 160 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1763 "JfifSupport.c"
}


GType
jpeg_marker_get_type (void)
{
	static volatile gsize jpeg_marker_type_id__volatile = 0;
	if (g_once_init_enter (&jpeg_marker_type_id__volatile)) {
		static const GEnumValue values[] = {{JPEG_MARKER_INVALID, "JPEG_MARKER_INVALID", "invalid"}, {JPEG_MARKER_SOI, "JPEG_MARKER_SOI", "soi"}, {JPEG_MARKER_EOI, "JPEG_MARKER_EOI", "eoi"}, {JPEG_MARKER_APP0, "JPEG_MARKER_APP0", "app0"}, {JPEG_MARKER_APP1, "JPEG_MARKER_APP1", "app1"}, {0, NULL, NULL}};
		GType jpeg_marker_type_id;
		jpeg_marker_type_id = g_enum_register_static ("JpegMarker", values);
		g_once_init_leave (&jpeg_marker_type_id__volatile, jpeg_marker_type_id);
	}
	return jpeg_marker_type_id__volatile;
}


gint
jpeg_quality_get_pct (JpegQuality self)
{
	gint result = 0;
#line 171 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = (gint) self;
#line 171 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1789 "JfifSupport.c"
}


gchar*
jpeg_quality_get_pct_text (JpegQuality self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
#line 175 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = g_strdup_printf ("%d", (gint) self);
#line 175 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp0_;
#line 175 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1804 "JfifSupport.c"
}


JpegQuality*
jpeg_quality_get_all (int* result_length1)
{
	JpegQuality* result = NULL;
	JpegQuality* _tmp0_;
	JpegQuality* _tmp1_;
	gint _tmp1__length1;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = g_new0 (JpegQuality, 4);
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_[0] = JPEG_QUALITY_LOW;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_[1] = JPEG_QUALITY_MEDIUM;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_[2] = JPEG_QUALITY_HIGH;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_[3] = JPEG_QUALITY_MAXIMUM;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = _tmp0_;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1__length1 = 4;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (result_length1) {
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		*result_length1 = _tmp1__length1;
#line 1833 "JfifSupport.c"
	}
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp1_;
#line 179 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1839 "JfifSupport.c"
}


gchar*
jpeg_quality_to_string (JpegQuality self)
{
	gchar* result = NULL;
#line 183 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	switch (self) {
#line 183 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		case JPEG_QUALITY_LOW:
#line 1851 "JfifSupport.c"
		{
			gchar* _tmp0_;
#line 185 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			_tmp0_ = g_strdup_printf (_ ("Low (%d%%)"), (gint) self);
#line 185 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			result = _tmp0_;
#line 185 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			return result;
#line 1860 "JfifSupport.c"
		}
#line 183 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		case JPEG_QUALITY_MEDIUM:
#line 1864 "JfifSupport.c"
		{
			gchar* _tmp1_;
#line 188 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			_tmp1_ = g_strdup_printf (_ ("Medium (%d%%)"), (gint) self);
#line 188 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			result = _tmp1_;
#line 188 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			return result;
#line 1873 "JfifSupport.c"
		}
#line 183 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		case JPEG_QUALITY_HIGH:
#line 1877 "JfifSupport.c"
		{
			gchar* _tmp2_;
#line 191 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			_tmp2_ = g_strdup_printf (_ ("High (%d%%)"), (gint) self);
#line 191 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			result = _tmp2_;
#line 191 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			return result;
#line 1886 "JfifSupport.c"
		}
#line 183 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		case JPEG_QUALITY_MAXIMUM:
#line 1890 "JfifSupport.c"
		{
			gchar* _tmp3_;
#line 194 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			_tmp3_ = g_strdup_printf (_ ("Maximum (%d%%)"), (gint) self);
#line 194 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			result = _tmp3_;
#line 194 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			return result;
#line 1899 "JfifSupport.c"
		}
		default:
#line 183 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		break;
#line 1904 "JfifSupport.c"
	}
#line 197 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_warn_if_reached ();
#line 199 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = NULL;
#line 199 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1912 "JfifSupport.c"
}


GType
jpeg_quality_get_type (void)
{
	static volatile gsize jpeg_quality_type_id__volatile = 0;
	if (g_once_init_enter (&jpeg_quality_type_id__volatile)) {
		static const GEnumValue values[] = {{JPEG_QUALITY_LOW, "JPEG_QUALITY_LOW", "low"}, {JPEG_QUALITY_MEDIUM, "JPEG_QUALITY_MEDIUM", "medium"}, {JPEG_QUALITY_HIGH, "JPEG_QUALITY_HIGH", "high"}, {JPEG_QUALITY_MAXIMUM, "JPEG_QUALITY_MAXIMUM", "maximum"}, {0, NULL, NULL}};
		GType jpeg_quality_type_id;
		jpeg_quality_type_id = g_enum_register_static ("JpegQuality", values);
		g_once_init_leave (&jpeg_quality_type_id__volatile, jpeg_quality_type_id);
	}
	return jpeg_quality_type_id__volatile;
}


gboolean
jpeg_is_jpeg (GFile* file,
              GError** error)
{
	gboolean result = FALSE;
	GFileInputStream* fins = NULL;
	GFileInputStream* _tmp0_;
	gboolean _tmp2_ = FALSE;
	GFileInputStream* _tmp3_;
	GError * _inner_error_ = NULL;
#line 203 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 204 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = g_file_read (file, NULL, &_inner_error_);
#line 204 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	fins = _tmp0_;
#line 204 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1948 "JfifSupport.c"
		gboolean _tmp1_ = FALSE;
#line 204 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 204 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return _tmp1_;
#line 1954 "JfifSupport.c"
	}
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp3_ = fins;
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2_ = jpeg_is_jpeg_stream (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, g_input_stream_get_type (), GInputStream), &_inner_error_);
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1962 "JfifSupport.c"
		gboolean _tmp4_ = FALSE;
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (fins);
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return _tmp4_;
#line 1970 "JfifSupport.c"
	}
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp2_;
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_g_object_unref0 (fins);
#line 205 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 1978 "JfifSupport.c"
}


gboolean
jpeg_is_jpeg_stream (GInputStream* ins,
                     GError** error)
{
	gboolean result = FALSE;
	JpegMarker marker = 0;
	gint segment_length = 0;
	JpegMarker _tmp0_ = 0;
	gint _tmp1_;
	gboolean _tmp3_ = FALSE;
	GError * _inner_error_ = NULL;
#line 208 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (G_IS_INPUT_STREAM (ins), FALSE);
#line 210 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = jpeg_read_marker (ins, &_tmp0_, &_inner_error_);
#line 210 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	marker = _tmp0_;
#line 210 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	segment_length = _tmp1_;
#line 210 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2003 "JfifSupport.c"
		gboolean _tmp2_ = FALSE;
#line 210 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 210 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return _tmp2_;
#line 2009 "JfifSupport.c"
	}
#line 213 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (marker == JPEG_MARKER_SOI) {
#line 213 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp3_ = segment_length == 0;
#line 2015 "JfifSupport.c"
	} else {
#line 213 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp3_ = FALSE;
#line 2019 "JfifSupport.c"
	}
#line 213 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp3_;
#line 213 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 2025 "JfifSupport.c"
}


gboolean
jpeg_is_jpeg_bytes (GBytes* bytes,
                    GError** error)
{
	gboolean result = FALSE;
	GMemoryInputStream* mins = NULL;
	GMemoryInputStream* _tmp0_;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 216 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (bytes != NULL, FALSE);
#line 217 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = (GMemoryInputStream*) g_memory_input_stream_new_from_bytes (bytes);
#line 217 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	mins = _tmp0_;
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = jpeg_is_jpeg_stream (G_TYPE_CHECK_INSTANCE_CAST (mins, g_input_stream_get_type (), GInputStream), &_inner_error_);
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2048 "JfifSupport.c"
		gboolean _tmp2_ = FALSE;
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (mins);
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return _tmp2_;
#line 2056 "JfifSupport.c"
	}
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp1_;
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_g_object_unref0 (mins);
#line 219 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 2064 "JfifSupport.c"
}


gint
jpeg_read_marker (GInputStream* fins,
                  JpegMarker* marker,
                  GError** error)
{
	JpegMarker _vala_marker = 0;
	gint result = 0;
	GDataInputStream* dins = NULL;
	GDataInputStream* _tmp0_;
	GDataInputStream* _tmp1_;
	guint8 _tmp2_ = 0U;
	GDataInputStream* _tmp3_;
	guint8 _tmp5_ = 0U;
	GDataInputStream* _tmp6_;
	gboolean _tmp8_ = FALSE;
	JpegMarker _tmp9_;
	guint16 length = 0U;
	GDataInputStream* _tmp11_;
	gboolean _tmp13_ = FALSE;
	guint16 _tmp14_;
	guint16 _tmp16_;
	GError * _inner_error_ = NULL;
#line 222 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_return_val_if_fail (G_IS_INPUT_STREAM (fins), 0);
#line 223 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_vala_marker = JPEG_MARKER_INVALID;
#line 225 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp0_ = g_data_input_stream_new (fins);
#line 225 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	dins = _tmp0_;
#line 226 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp1_ = dins;
#line 226 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	g_data_input_stream_set_byte_order (_tmp1_, G_DATA_STREAM_BYTE_ORDER_BIG_ENDIAN);
#line 228 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp3_ = dins;
#line 228 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp2_ = g_data_input_stream_read_byte (_tmp3_, NULL, &_inner_error_);
#line 228 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2108 "JfifSupport.c"
		gint _tmp4_ = 0;
#line 228 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 228 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (dins);
#line 228 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return _tmp4_;
#line 2116 "JfifSupport.c"
	}
#line 228 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (_tmp2_ != JPEG_MARKER_PREFIX) {
#line 229 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		result = -1;
#line 229 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (dins);
#line 229 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		if (marker) {
#line 229 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			*marker = _vala_marker;
#line 2128 "JfifSupport.c"
		}
#line 229 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return result;
#line 2132 "JfifSupport.c"
	}
#line 231 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp6_ = dins;
#line 231 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp5_ = g_data_input_stream_read_byte (_tmp6_, NULL, &_inner_error_);
#line 231 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2140 "JfifSupport.c"
		gint _tmp7_ = 0;
#line 231 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 231 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (dins);
#line 231 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return _tmp7_;
#line 2148 "JfifSupport.c"
	}
#line 231 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_vala_marker = (JpegMarker) _tmp5_;
#line 232 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp9_ = _vala_marker;
#line 232 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (_tmp9_ == JPEG_MARKER_SOI) {
#line 232 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp8_ = TRUE;
#line 2158 "JfifSupport.c"
	} else {
		JpegMarker _tmp10_;
#line 232 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp10_ = _vala_marker;
#line 232 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp8_ = _tmp10_ == JPEG_MARKER_EOI;
#line 2165 "JfifSupport.c"
	}
#line 232 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (_tmp8_) {
#line 234 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		result = 0;
#line 234 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (dins);
#line 234 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		if (marker) {
#line 234 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			*marker = _vala_marker;
#line 2177 "JfifSupport.c"
		}
#line 234 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return result;
#line 2181 "JfifSupport.c"
	}
#line 237 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp11_ = dins;
#line 237 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	length = g_data_input_stream_read_uint16 (_tmp11_, NULL, &_inner_error_);
#line 237 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2189 "JfifSupport.c"
		gint _tmp12_ = 0;
#line 237 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 237 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (dins);
#line 237 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return _tmp12_;
#line 2197 "JfifSupport.c"
	}
#line 238 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp14_ = length;
#line 238 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (((gint) _tmp14_) < 2) {
#line 238 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (fins, g_seekable_get_type ());
#line 2205 "JfifSupport.c"
	} else {
#line 238 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp13_ = FALSE;
#line 2209 "JfifSupport.c"
	}
#line 238 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (_tmp13_) {
#line 2213 "JfifSupport.c"
		guint16 _tmp15_;
#line 239 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_tmp15_ = length;
#line 239 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		g_debug ("Invalid length %Xh at ofs %" G_GINT64_FORMAT "Xh", _tmp15_, g_seekable_tell (G_TYPE_CHECK_INSTANCE_TYPE (fins, g_seekable_get_type ()) ? ((GSeekable*) fins) : NULL) - 2);
#line 242 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		result = -1;
#line 242 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		_g_object_unref0 (dins);
#line 242 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		if (marker) {
#line 242 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
			*marker = _vala_marker;
#line 2227 "JfifSupport.c"
		}
#line 242 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		return result;
#line 2231 "JfifSupport.c"
	}
#line 246 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_tmp16_ = length;
#line 246 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	result = _tmp16_ - 2;
#line 246 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	_g_object_unref0 (dins);
#line 246 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	if (marker) {
#line 246 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
		*marker = _vala_marker;
#line 2243 "JfifSupport.c"
	}
#line 246 "/home/jens/Source/shotwell/src/photos/JfifSupport.vala"
	return result;
#line 2247 "JfifSupport.c"
}



